@@ -3,6 +3,16 @@
 # This is kernel build script for ubuntu 8.04's 2.6.24 kernel.
 #
 
+update_maintainer () {
+    for i in debian*/control debian*/control.stub*
+    do
+	cp -p $i $i.orig
+	sed -i -e 's/Maintainer: .*/Maintainer: Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>/' -- $i
+	touch -r $i.orig $i
+	rm $i.orig
+    done
+}
+
 die () {
     echo $1
     exit 1
@@ -21,9 +31,9 @@ done
 # Download TOMOYO Linux patches.
 mkdir -p /usr/src/rpm/SOURCES/
 cd /usr/src/rpm/SOURCES/ || die "Can't chdir to /usr/src/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.9-20120511.tar.gz ]
+if [ ! -r ccs-patch-1.6.9-20130310.tar.gz ]
 then
-    wget -O ccs-patch-1.6.9-20120511.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20120511.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.6.9-20130310.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20130310.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -39,10 +49,11 @@ apt-get source linux-restricted-modules-${VERSION}-generic || die "Can't install
 
 # Copy patches and create kernel config.
 cd linux-2.6.24/ || die "Can't chdir to linux-2.6.24/ ."
+update_maintainer
 mkdir -p debian/binary-custom.d/ccs/patchset || die "Can't create debian/binary-custom.d/ccs/patchset ."
 mkdir -p ccs-patch/ || die "Can't create directory."
 cd ccs-patch/ || die "Can't chdir to ccs-patch/ ."
-tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.9-20120511.tar.gz || die "Can't extract patch."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.9-20130310.tar.gz || die "Can't extract patch."
 cp -p patches/ccs-patch-2.6.24-ubuntu-8.04.diff ../debian/binary-custom.d/ccs/patchset/ubuntu-8.04.patch || die "Can't copy patch."
 rm -fR specs/ patches/ || die "Can't delete directory."
 for i in `find . -type f`; do diff -u /dev/null $i; done > ../debian/binary-custom.d/ccs/patchset/ccs.patch
@@ -51,10 +62,11 @@ cd debian/binary-custom.d/ccs/ || die "Can't chdir to debian/binary-custom.d/ccs
 cat ../../config/i386/config ../../config/i386/config.generic ../../../ccs-patch/config.ccs > config.i386 || die "Can't create config."
 sed -i -e 's:CONFIG_DEBUG_INFO=.*:# CONFIG_DEBUG_INFO is not set:' -- config.i386 || die "Can't edit config."
 touch rules || die "Can't create file."
+sed -e 's@do_debug="Yes"@do_debug="No"@' ../../control.d/vars.generic > vars
 cd ../../../ || die "Can't chdir to ../../../ ."
 rm -fR ccs-patch || die "Can't delete directory."
-awk ' BEGIN { flag = 0; print ""; } { if ($1 == "Package:" ) { if (index($0, "-generic") > 0) flag = 1; else flag = 0; }; if (flag) print $0; } ' debian/control.stub | sed -e 's:-generic:-ccs:' > debian/control.stub.ccs || die "Can't create file."
-cat debian/control.stub.ccs >> debian/control.stub || die "Can't edit file."
+echo 'all_custom_flavours += ccs' >> debian/rules.d/0-common-vars.mk
+for i in debian/rules.d/[a-zA-Z]*.mk; do echo 'custom_flavours += ccs' >> $i; done
 debian/rules debian/control || die "Can't run control."
 
 # Start compilation.
@@ -64,6 +76,7 @@ cd ../ || die "Can't chdir to ../ ."
 # Install header package for compiling additional modules.
 dpkg -i linux-headers-*-ccs*.deb || die "Can't install packages."
 cd linux-ubuntu-modules-2.6.24-2.6.24 || die "Can't chdir to linux-ubuntu-modules-2.6.24-2.6.24 ."
+update_maintainer
 awk ' BEGIN { flag = 0; print ""; } { if ($1 == "Package:" ) { if (index($0, "-generic") > 0) flag = 1; else flag = 0; }; if (flag) print $0; } ' debian/control.stub | sed -e 's:-generic:-ccs:' > debian/control.stub.ccs || die "Can't create file."
 cat debian/control.stub.ccs >> debian/control.stub || die "Can't edit file."
 debian/rules debian/control || die "Can't run control."
@@ -72,6 +85,7 @@ debian/rules binary-indep binary-arch || die "Failed to build kernel package."
 cd .. || die "Can't chdir to ../ ."
 
 cd linux-restricted-modules-2.6.24-2.6.24.18/ || die "Can't chdir to linux-restricted-modules-2.6.24-2.6.24.18/ ."
+update_maintainer
 awk ' BEGIN { flag = 0; print ""; } { if ( $1 == "Package:") { if ( index($2, "-generic") > 0) flag = 1; else flag = 0; }; if (flag) print $0; } ' debian/control.stub.in | sed -e 's:-generic:-ccs:g' > debian/control.stub.in.tmp || die "Can't create file."
 cat debian/control.stub.in.tmp >> debian/control.stub.in || die "Can't edit file."
 sed -i -e 's/,generic/,ccs generic/' debian/rules || die "Can't edit file."
